@echo off
rem # ====================================================================
rem #
rem # OpenCCM: The Open CORBA Component Model Platform
rem # Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
rem # Contact: openccm@objectweb.org
rem #
rem # This library is free software; you can redistribute it and/or
rem # modify it under the terms of the GNU Lesser General Public
rem # License as published by the Free Software Foundation; either
rem # version 2.1 of the License, or any later version.
rem #
rem # This library is distributed in the hope that it will be useful,
rem # but WITHOUT ANY WARRANTY; without even the implied warranty of
rem # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
rem # Lesser General Public License for more details.
rem #
rem # You should have received a copy of the GNU Lesser General Public
rem # License along with this library; if not, write to the Free Software
rem # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
rem # USA
rem #
rem # Initial developer(s): Briclet Frederic
rem # Contributor(s): Philippe Merle, Jerome Moroy.
rem #
rem # ====================================================================
rem #
rem # Starting an OpenCCM DCI Manager.
rem #
rem # ====================================================================

setlocal

rem #  =====================
rem #  Compute Command Line
rem #  =====================

set /a nb_args=0
for %%i in (%*) do set /a nb_args=nb_args+1

if %nb_args% == 0 goto help
rem # if %nb_args% > 1 goto help


set /a nb=0
set with_tracing="false"
set services_list=

:initial
if "%1"=="-h" goto :help
if "%1"=="?" goto :help
if "%1" == "--tracing" goto tracing
if %nb% == %nb_args% (goto end_command_line) else (goto set_name)

:tracing
set XBOOTCLASSPATH=%OpenCCM_HOMEDIR%\lib\coach_tracing_toolkit.jar;
set with_tracing="true"
set services_list=%services_list% Tracing
shift
set /a nb=nb+1
goto initial

:set_name
set dci_name=%1
shift
set /a nb=nb+1
goto initial

:help
echo "usage: dci_start [--tracing] <dci_name>"    
goto :eof

:end_command_line

:start
set dci_path=%OpenCCM_CONFIG_DIR%\DCIManagers\%dci_name%\%dci_name%

rem # Create the %dci_path% directory
if exist %dci_path% goto dci_dir_exists
mkdir %dci_path%

:dci_dir_exists

rem #  ============================
rem #  OpenCCM Platform installed ?
rem #  ============================

:platform_installed
call %OpenCCM_HOMEDIR%\bin\ccm_installed
if %CCM_INSTALLED%==0 goto :eof

rem #  ======================
rem #  Name Service started ?
rem #  ======================

rem # Obtain the IOR of the started Name Service.
call ns_ior > %OpenCCM_CONFIG_DIR%\DCIManagers\%dci_name%.tmp
for /f %%i in (%OpenCCM_CONFIG_DIR%\DCIManagers\%dci_name%.tmp) do set ior_NS=%%i
del %OpenCCM_CONFIG_DIR%\DCIManagers\%dci_name%.tmp

rem # Check if a Name Service is started.
if defined ior_NS goto test_dci

echo Error: The Name Service is not started!
goto :eof

:test_dci

rem #  =============
rem #  DCI started ?
rem #  =============

rem # Check if this Java Component Server is already started.
if not exist %dci_path%.PID goto :dci_not_started

echo Error: The OpenCCM DCI Manager %dci_name%  is already started!
goto :eof

:dci_not_started

if NOT EXIST %OpenCCM_CONFIG_DIR%\DCIManagers (
  echo Creating the %OpenCCM_CONFIG_DIR%\DCIManagers directory.
  mkdir %OpenCCM_CONFIG_DIR%\DCIManagers
)

echo The OpenCCM DCI Manager %dci_name% will be started.

mkdir %OpenCCM_CONFIG_DIR%\DCIManagers\%dci_name%

set jvm_args="-Dior_ns=%ior_NS%"

set run_id=dci_start


:service_tracing
if %with_tracing% == "false" goto run
set run_id=%run_id%_tracing


:run
set args="--runid %run_id% -arg NSREGISTER=OpenCCM/DCIManagers/%dci_name% -arg DCINAME=%dci_name% -arg IORPATH=%dci_path%.IOR file:%OpenCCM_HOMEDIR%\xml\launcher\dci_server.xml"

echo Launching the OpenCCM DCI Manager %dci_name%.

set LAUNCHER_JVM_ARGS="%jvm_args%"
set LAUNCHER_ARGS="%args%"
call openccm_launcher fork %dci_path%.output %dci_path%.PID

rem # Wait for the IOR file produced.
:wait
set READY=
if not exist %dci_path%.IOR goto :wait

rem # fix the Current DCI URL
copy %dci_path%.IOR %OpenCCM_CONFIG_DIR%\DCI.IOR > nul

echo The OpenCCM DCI Manager %dci_name% is started.
