/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s): ___________________________________.

====================================================================*/

package DiningPhilosophers.explorer;

import DiningPhilosophers.*;
import org.omg.Components.EventBase;
import org.omg.Components.BadEventType;

/**
 * This is an implementation of the OMG IDL 
 * DiningPhilosophers::StatusInfoConsumer component type.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 *
 */
public class StatusInfoConsumerImpl
     extends StatusInfoConsumerPOA
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    
    /** The panel to refresh. */
    protected DiningPhilosophers.cif.PhilosopherPanel panel_ = null;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** 
     * Default constructor.
     * @param panel The panel to refresh.
     */
    public StatusInfoConsumerImpl(DiningPhilosophers.cif.PhilosopherPanel panel){
        panel_ = panel;
    }

    // ==================================================================
    //
    // Methods for OMG IDL org::omg::Components::EventConsumerBase
    //
    // ==================================================================

    //
    // IDL:omg.org/Components/EventConsumerBase/push_event:1.0
    //
    /**
     * This method does nothing.
     */
    public void
    push_event(EventBase evt)
    throws BadEventType
    {
        // Nothing to do
    }
        
    // ==================================================================
    //
    // Methods for OMG IDL DiningPhilosophers::StatusInfoConsumer
    //
    // ==================================================================

    //
    // IDL:DiningPhilosophers/StatusInfoConsumer/push_StatusInfo:1.0
    //
    /**
     * Update the panel according to the given StatusInfo.
     */
    public void
    push_StatusInfo(StatusInfo the_statusinfo)
    {
        if(panel_!=null)
            panel_.updatePanel(the_statusinfo);
    }

}