
/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Areski Flissi.
Contributor(s): 

====================================================================*/

package org.objectweb.ccm.filetransfer.cif;

//import org.objectweb.ccm.filetransfer.*;

/**
 * This is the implementation of the OMG IDL3 filetransfer::Prog component type.
 *
 * This class inherits from the local CCM_Prog interface
 * generated by the OpenCCM's IDL3 to IDL2 mapping generator.
 *
 * 
 * @author <a href="mailto:Areski.Flissi@lifl.fr">Areski Flissi</A>
 */

public class ProgImpl
    extends org.objectweb.ccm.filetransfer.ProgSessionComposition.ComponentImpl
    implements java.lang.Runnable, java.awt.event.ActionListener {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The name of the component. */
    private String name_;

    private String prog_dir;
    private String[] fileList = null;
    

    private Thread the_prog;

    /** To refer to the GUI frame. */
    private java.awt.Frame frame_;
    private java.awt.Button button_start;

    /** To refer to the GUI user output area. */
    private java.awt.TextArea textArea_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public ProgImpl() {

        
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for OMG IDL Components::EnterpriseComponent
    //
    // ==================================================================

    /**
     * Complete the component configuration.
     *
     * @exception org.omg.Components.InvalidConfiguration
     *            Thrown if the configuration is invalid.
     */
    public void configuration_complete()
        throws org.omg.Components.InvalidConfiguration {

        // Checks if the configuration is not completed.
        if (name_ == null)
            throw new org.omg.Components.InvalidConfiguration();

//        // Instantiating the GUI.
//        // Creates a AWT Frame.
//        frame_ = new java.awt.Frame("The " + name_ + " Prog's GUI");
//
//        // Creates a text area for displaying inputs.
//        textArea_ = new java.awt.TextArea(12, 40);
//        textArea_.setEditable(false);
//
//        //button_start = new java.awt.Button("Start");
//        //button_start.addActionListener(this);
//
//        // Constructs and shows the GUI.
//        java.awt.Panel panel = new java.awt.Panel(new java.awt.BorderLayout());
//        frame_.setLayout(new java.awt.BorderLayout());
//        frame_.add(panel);
//
//        panel.add(textArea_, java.awt.BorderLayout.NORTH);
//        //panel.add(button_start, java.awt.BorderLayout.CENTER);
//
//        frame_.pack();
//        frame_.show();

        //  Start a new thread to send files.
        the_prog = new java.lang.Thread(this);
        the_prog.start();

        
    }

    // ==================================================================
    //
    // Methods for the OMG IDL org.omg.Components.SessionComponent
    //
    // ==================================================================

    /**
     * Container callback to signal that the component is removed.
     *
     * @throw org.omg.Components.CCMException For any problems.
     */
    public void ccm_remove() throws org.omg.Components.CCMException {

    }

    // ==================================================================
    //
    // Methods for the OMG IDL filetransfer::CCM_Prog interface.
    //
    // ==================================================================

    /**
         * The mutator method for the attribute name.
         *
         * @param n The name.
         */
    public void the_name(String n) {
        name_ = n;

    }

    /**
     * The accessor method for the attribute name.
     *
     * @return The name.
     */
    public String the_name() {
        return name_;
    }

    // ==================================================================
    //
    // Methods for sending files to connected channels.
    //
    // ==================================================================

    public void send_files() {

        // Getting the Prog directory
        
              
        java.io.File currentdir = new java.io.File(System.getProperty("user.dir"));               
        currentdir = new java.io.File(currentdir.getParent());           
        java.io.File path = new java.io.File(currentdir.getParent() + "/IMAGE/Send/" + name_);
        System.out.println(path); 
        
        
        fileList = path.list();

        // Sending all files
        for (int i = 0; i < fileList.length; i++) {
            
            
            
            java.io.File testfile = new java.io.File(path + "/" + fileList[i]);
            if (testfile.isFile()) {
            
            //
            // Read data from the file to be transferred
            //
            java.io.FileInputStream inStream = null;

            try {
                
                
                System.out.println(
                    "Sending "
                        + path
                        + "\\"
                        + fileList[i]
                        + " from "
                        + name_
                        + " to Channel component");
                inStream =
                    new java.io.FileInputStream(path + "/" + fileList[i]);
            } catch (java.io.FileNotFoundException ex) {
                System.err.println(
                    "Can't open file " + fileList[i] + ex.getMessage());

            }

            byte[] file = null;
            try {
                file = new byte[inStream.available()];
                inStream.read(file);
                inStream.close();
            } catch (java.io.IOException ex) {
                System.err.println(
                    "Can't read from " + fileList[i] + ex.getMessage());

            }

            //
            // Send the file
            //

            get_context().push_to_channels(new ImagesImpl(file, fileList[i]));

            //textArea_.append("Sending " + fileList[i] + "..." + "\n");

            // Gros dodo pendant x secondes
            try {
                Thread.sleep(2000);
            } catch (InterruptedException ex) {
                // None
            }
            }
        }

    }

    public void run() {

        for (int j = 0; j < 100; j++) {
            this.send_files();

        }

    }

    //  ==================================================================
    //
    // Methods for interface java.awt.event.ActionListener
    //
    // ==================================================================

    /**
     * When the button is selectionned.
     *
     * @param e The associate ActionEvent.
     */
    public void actionPerformed(java.awt.event.ActionEvent e) {

        //  Start a new thread to send files.
        the_prog = new java.lang.Thread(this);
        the_prog.start();

    }

}
